@@ -58,11 +58,20 @@ setMethod("BIC", signature = "fmrsfit", BIC.fmrsfit)
 #' @aliases summary,summary-method
 setMethod("summary", signature = "fmrsfit", summary.fmrsfit)
 
+#' @rdname summary-methods
+#' @rdname fmrstunpar-class
+#' @aliases summary,summary-method
+setMethod("summary", signature = "fmrstunpar", summary.fmrstunpar)
+
 #' @rdname show-methods
 #' @rdname fmrsfit-class
 #' @aliases show,show-method
 setMethod("show", signature = "fmrsfit", show.fmrsfit)
 
+#' @rdname show-methods
+#' @rdname fmrstunpar-class
+#' @aliases show,show-method
+setMethod("show", signature = "fmrstunpar", show.fmrstunpar)
 
 #' @rdname fmrs.mle-methods
 #' @aliases fmrs.mle-method
@@ -80,7 +89,8 @@ setMethod(f="fmrs.mle", definition=function(y,
                                          conveps = 1e-8,
                                          convepsEM = 1e-8,
                                          convepsNR = 1e-8,
-                                         porNR = 2){
+                                         porNR = 2,
+                                         activeset){
   if(missing(y) | !is.numeric(y))
     stop("A numeric response vector must be provided.")
   if(missing(x) | !is.numeric(x))
@@ -89,7 +99,7 @@ setMethod(f="fmrs.mle", definition=function(y,
     stop("A censoring indicator vector with 0 or 1 values must be provided.")
 
     if((nComp<2) ) {
-    stop("An interger greater than 2 for the order of mixture model
+    stop("An interger greater than 1 for the order of mixture model
          must be provided.")
   }
   nCov = dim(x)[2]
@@ -98,10 +108,15 @@ setMethod(f="fmrs.mle", definition=function(y,
   if(missing(initDispersion)) initDispersion = rep(1,nComp)
   if(missing(initmixProp)) initmixProp = rep(1/nComp,nComp)
 
-  coef0 <- matrix(c(initCoeff), nrow = nComp, ncol = nCov+1, byrow = TRUE)
+  if(missing(activeset)) activeset = matrix(1, nrow = nCov+1, ncol = nComp)
+  if(any(activeset!=0 & activeset!=1))
+    stop("activeset must be a matrix of dimention nCov+1 by nComp with
+         only 0 and 1 values.")
+
+    coef0 <- matrix(c(initCoeff), nrow = nComp, ncol = nCov+1, byrow = TRUE)
 
   if(is.null(colnames(x))){
-    xnames <- c("Intercept",c(paste("Cov",1:nCov,sep=".")))
+    xnames <- c("Intercept",c(paste("X",1:nCov,sep=".")))
   } else{
     xnames <- c("Intercept",colnames(x))
   }
@@ -139,7 +154,9 @@ setMethod(f="fmrs.mle", definition=function(y,
            GIC = as.double(0),
            predict = as.double(rep(0,n*nComp)),
            residual = as.double(rep(0,n*nComp)),
-           tau = as.double(rep(0,n*nComp))
+           tau = as.double(rep(0,n*nComp)),
+           actset = as.integer(activeset),
+           disnorm = as.integer(1)
     )
   }else if(disFamily == "lnorm"){
     model = "FMAFTR"
@@ -173,12 +190,15 @@ setMethod(f="fmrs.mle", definition=function(y,
            GIC = as.double(0),
            predict = as.double(rep(0,n*nComp)),
            residual = as.double(rep(0,n*nComp)),
-           tau = as.double(rep(0,n*nComp))
+           tau = as.double(rep(0,n*nComp)),
+           actset = as.integer(activeset),
+           disnorm = as.integer(2)
     )
 
   }else if(disFamily == "weibull"){
     model = "FMAFTR"
     logy = log(y)
+
     res=.C("FMR_Weibl_Surv_EM_MLE", PACKAGE="fmrs",
            y = as.double(logy),
            x = as.double(as.vector(unlist(x))),
@@ -209,12 +229,212 @@ setMethod(f="fmrs.mle", definition=function(y,
            GIC = as.double(0),
            predict = as.double(rep(0,n*nComp)),
            residual = as.double(rep(0,n*nComp)),
-           tau = as.double(rep(0,n*nComp))
+           tau = as.double(rep(0,n*nComp)),
+           actset = as.integer(activeset)
     )
+
+    if(res$LogLikelihood=='NaN'){
+      fmrs.mle2 <- function(y,
+                            x,
+                            delta,
+                            Lambda.Ridge,
+                            Num.Comp,
+                            Num.Cov,
+                            Sample.Size,
+                            Num.iterationEM,
+                            Num.iterationNR,
+                            PortionNF,
+                            Initial.Intercept,
+                            Initial.Coefficient,
+                            Initial.Dispersion,
+                            Initial.mixProp,
+                            conv.eps.em,
+                            actset
+      )
+      {
+        require(survival)
+        x <- matrix(c(x),Sample.Size,Num.Cov)
+        acs=matrix(c(actset),nCov+1,nComp)
+        new_pi0 <- pi0 <- c(Initial.mixProp)
+        new_beta0 <- beta0 <- matrix(Initial.Coefficient,nCov,nComp)
+        new_alpha0 <- alpha0 <- c(Initial.Intercept)
+        new_sigma0 <- sigma0 <- c(Initial.Dispersion)
+
+        phi <- matrix(0, Sample.Size, Num.Comp)
+        W <- predict <- residual <- matrix(0, Sample.Size, Num.Comp)
+        sumwi <- matrix(0, Num.Comp)
+
+        emiter = 0
+        CONV = 0
+        while ((emiter<Num.iterationEM) & (CONV!=1)) {
+          for (k1 in 1:Num.Comp) {
+            sumwi[k1] = 0
+          }
+
+          for (i in 1:Sample.Size) {
+            sumi = 0.0
+            for (k1 in 1:Num.Comp) {
+              mui = sum(x[i,] * beta0[,k1] * acs[-1,k1])
+              mui = mui + alpha0[k1] * acs[1,k1]
+              deni = (((1 / sigma0[k1])* exp((log(y[i]) - mui) / sigma0[k1]))^(delta[i])) * exp(-exp((log(y[i]) - mui) / sigma0[k1]))
+              if(deni==0)
+                deni= 0.000001
+              phi[i,k1] = pi0[k1] * deni
+              sumi = sumi + phi[i,k1]
+            }
+            for(k1 in 1:Num.Comp)
+            {
+              W[i,k1] = phi[i,k1] / sumi
+              if(W[i,k1]<1e-10) W[i,k1] = 1e-10
+              sumwi[k1] = sumwi[k1] + W[i,k1]
+            }
+          }
+
+          for(k1 in 1:Num.Comp){
+            new_pi0[k1] = sumwi[k1] / Sample.Size;
+          }
+
+          for(k1 in 1:Num.Comp)
+          {
+            newX = x[,acs[-1,k1]==1]
+            if(acs[1,k1]==1){
+              res <- survival::survreg(Surv(time = y, event = delta, type = c('right')) ~ 1 + newX , weights = W[,k1],
+                             dist="weibull", init=c(alpha0[k1],beta0[acs[-1,k1]==1,k1]), scale=sigma0[k1],
+                             control=list(maxiter=Num.iterationNR, rel.tolerance=conv.eps.em,
+                                                     toler.chol=conv.eps.em, iter.max=Num.iterationNR, debug=0, outer.max=10),parms=NULL,model=FALSE, x=FALSE,
+                             y=TRUE, robust=FALSE, score=FALSE)
+              new_alpha0[k1] <- as.double(coef(res)[1])
+              new_beta0[acs[-1,k1]==1,k1] <- as.double(coef(res)[-1])
+              new_beta0[acs[-1,k1]==0,k1] <- 0
+            }
+            else{
+              res <- survival::survreg(Surv(time = y, event = delta, type = c('right')) ~ -1 + newX , weights = W[,k1],
+                             dist="weibull", init=c(beta0[acs[-1,k1]==1,k1]), scale=sigma0[k1],
+                             control=list(maxiter=Num.iterationNR, rel.tolerance=conv.eps.em,
+                                                     toler.chol=conv.eps.em, iter.max=Num.iterationNR, debug=0, outer.max=10),parms=NULL,model=FALSE, x=FALSE,
+                             y=TRUE, robust=FALSE, score=FALSE)
+              new_alpha0[k1] <- 0
+              new_beta0[acs[-1,k1]==1,k1] <- as.double(coef(res))
+              new_beta0[acs[-1,k1]==0,k1] <- 0
+            }
+            sumi3 = 0.0;
+            sumi5 = 0.0;
+
+            for(i in 1:Sample.Size){
+              mui = 0.0;
+              mui = sum(x[i,] * new_beta0[,k1] * acs[-1,k1])
+              mui = mui + new_alpha0[k1] * acs[1,k1]
+              sumi3 = sumi3 + W[i,k1] * (- delta[i] / sigma0[k1] + ((log(y[i]) - mui) / (sigma0[k1] * sigma0[k1])) * ( exp( (log(y[i]) - mui) / sigma0[k1]) - delta[i])   )
+              sumi5 = sumi5 + W[i,k1] * ( delta[i] / (sigma0[k1] * sigma0[k1]) +  ((log(y[i]) - mui) / (sigma0[k1] * sigma0[k1] * sigma0[k1])) * (2 * delta[i] - (2 + (log(y[i]) - mui) / sigma0[k1]) * exp( (log(y[i]) - mui) / sigma0[k1])  ))
+            }
+            new_sigma0[k1] = sigma0[k1] - (1 / sumi5) * sumi3;
+          }
+
+          emiter = emiter + 1
+
+          diff = sum((new_sigma0 - sigma0)^2) + sum((new_alpha0 - alpha0)^2) + sum((new_beta0 - beta0)^2) + sum((new_pi0-pi0)^2)
+          if(diff<conv.eps.em)
+            CONV = 1
+          sigma0 = new_sigma0
+          pi0 = new_pi0
+          alpha0 = new_alpha0
+          beta0 = new_beta0
+        }
+
+        loglike1 = 0.0
+
+
+        for(i in 1:Sample.Size){
+          sumi = 0.0;
+          for(k1 in 1:Num.Comp){
+            mui = sum(x[i,] * new_beta0[,k1] * acs[-1,k1]) + new_alpha0[k1] * acs[1,k1]
+            deni = (((1 / new_sigma0[k1])* exp((log(y[i]) - mui) / new_sigma0[k1]))^(delta[i])) * exp(-exp((log(y[i]) - mui) / new_sigma0[k1]))
+            phi[i,k1] = new_pi0[k1] * deni
+            sumi = sumi + phi[i,k1]
+          }
+          loglike1 = loglike1 + log(sumi)
+        }
+
+        BIC = loglike1 - 0.5 * Num.Comp * Num.Cov * log(Sample.Size)
+        EBIC5 = loglike1 - 0.5 * Num.Comp * Num.Cov * log(Sample.Size) - 0.5 * (Num.Comp * Num.Cov) * log(Num.Cov)
+        EBIC1 = loglike1 - 0.5 * (Num.Comp * Num.Cov) * log(Sample.Size) - (Num.Comp * Num.Cov) * log(Num.Cov)
+        AIC = loglike1 - (Num.Comp * Num.Cov)
+        GCV = (loglike1) / (Sample.Size * (1 - Num.Comp * Num.Cov / Sample.Size)^ 2)
+        GIC = loglike1 - 0.5 * (Num.Comp * Num.Cov) * log(Sample.Size)
+        MaxEMiter = emiter
+
+        for (i in 1:Sample.Size) {
+          sumi = 0.0
+          for (k1 in 1:Num.Comp) {
+            mui = sum(x[i,] * new_beta0[,k1] * acs[-1,k1]) + new_alpha0[k1] * acs[1,k1]
+            deni = (((1 / new_sigma0[k1])* exp((log(y[i]) - mui) / new_sigma0[k1]))^(delta[i])) * exp(-exp((log(y[i]) - mui) / new_sigma0[k1]))
+            if(deni==0)
+              deni= 0.000001
+            phi[i,k1] = new_pi0[k1] * deni
+            sumi = sumi + phi[i,k1]
+          }
+          for(k1 in 1:Num.Comp)
+          {
+            W[i,k1] = phi[i,k1] / sumi
+          }
+        }
+
+
+        for(k1 in 1:Num.Comp){
+          for(i in 1:Sample.Size){
+            mui = sum(x[i,] * new_beta0[,k1] * acs[-1,k1]) + new_alpha0[k1] * acs[1,k1]
+            predict[i,k1] = exp(mui)
+            residual[i,k1] = y[i] - exp(mui)
+          }
+        }
+
+
+        list(Intecept.Hat = c(new_alpha0),
+             Coefficient.Hat = c(new_beta0),
+             Dispersion.Hat = c(new_sigma0),
+             mixProp.Hat = c(new_pi0),
+             LogLikelihood = loglike1,
+             BIC = BIC,
+             AIC = AIC,
+             GCV = GCV,
+             EBIC1 = EBIC1,
+             EBIC5 = EBIC5,
+             GIC = GIC,
+             predict = c(predict),
+             residual = c(residual),
+             tau = c(W),
+             Max.iterEM.used = MaxEMiter
+        )
+      }
+
+      res <- fmrs.mle2(
+             y = as.double(y),
+             x = c(as.double(as.vector(unlist(x)))),
+             delta = as.double(delta),
+             Lambda.Ridge = as.double(lambRidge),
+             Num.Comp = as.integer(nComp),
+             Num.Cov = as.integer(nCov),
+             Sample.Size = as.integer(n),
+             Num.iterationEM = as.integer(nIterEM),
+             Num.iterationNR = 1,
+             PortionNF = as.integer(porNR),
+             Initial.Intercept = as.double(c(coef0[,1])),
+             Initial.Coefficient = as.double(c(t(coef0[,-1]))),
+             Initial.Dispersion = as.double(initDispersion),
+             Initial.mixProp = as.double(initmixProp),
+             conv.eps.em = as.double(convepsEM),
+             actset = as.integer(activeset)
+      )
+
+
+      print("The results are based on using survreg in survival package.")
+    }
+
   }else{
     stop("The family of sub-distributions is not specified correctly.")
   }
 
+
   fit <- new("fmrsfit",
              y = y,
              delta = delta,
@@ -245,7 +465,10 @@ setMethod(f="fmrs.mle", definition=function(y,
                                dimnames = list(NULL,comnames)),
              weights = array(matrix(res$tau, nrow = n, byrow = FALSE),
                              dim = c(n, nComp), dimnames =
-                               list(NULL,comnames))
+                               list(NULL,comnames)),
+             activeset = array(matrix(c(activeset), nrow=nCov+1, byrow = FALSE),
+                              dim = c(nCov+1, nComp),
+                              dimnames = list(xnames,comnames))
   )
   return(fit)
 })
@@ -271,8 +494,11 @@ setMethod(f="fmrs.tunsel", definition=function(y,
                                                convepsEM = 1e-8,
                                                convepsNR = 1e-8,
                                                porNR = 2,
-                                               gamMixPor = 1){
-
+                                               gamMixPor = 1,
+                                               activeset,
+                                               lambMCP,
+                                               lambSICA
+                                               ){
   if(missing(y) | !is.numeric(y))
     stop("A numeric response vector must be provided.")
   if(missing(x) | !is.numeric(x))
@@ -280,6 +506,12 @@ setMethod(f="fmrs.tunsel", definition=function(y,
   if(missing(delta) & (disFamily!="norm"))
     stop("A censoring indicator vector with 0 or 1 values must be provided.")
 
+  if(missing(lambMCP))
+    lambMCP = 2/(1-max(cor(x)[cor(x)!=1]))
+
+  if(missing(lambSICA))
+    lambSICA = 5.0
+
   if((nComp<2) ) {
     stop("An interger greater than 2 for the order of mixture model
          must be provided.")
@@ -289,9 +521,20 @@ setMethod(f="fmrs.tunsel", definition=function(y,
   if(missing(initCoeff)) initCoeff = rnorm((nCov+1)*nComp)
   if(missing(initDispersion)) initDispersion = rep(1,nComp)
   if(missing(initmixProp)) initmixProp = rep(1/nComp,nComp)
+  if(missing(activeset)) activeset = matrix(1, nrow = nCov+1, ncol = nComp)
+  if(any(activeset!=0 & activeset!=1))
+    stop("activeset must be a matrix of dimention nCov+1 by nComp with
+         only 0 and 1 values.")
 
   coef0 <- matrix(c(initCoeff), nrow = nComp, ncol = nCov+1, byrow = TRUE)
 
+  if(is.null(colnames(x))){
+    xnames <- c("Intercept",c(paste("X",1:nCov,sep=".")))
+  } else{
+    xnames <- c("Intercept",colnames(x))
+  }
+  comnames <- c(paste("Comp",1:nComp,sep="."))
+
   if(penFamily == "lasso") myPenaltyFamily = 1
   else if (penFamily == "scad") myPenaltyFamily = 2
   else if (penFamily == "mcp") myPenaltyFamily = 3
@@ -322,7 +565,10 @@ setMethod(f="fmrs.tunsel", definition=function(y,
            conv.eps = as.double(conveps),
            conv.eps.em = as.double(convepsEM),
            GamMixPortion = as.double(gamMixPor),
-           Opt.Lambda = as.double(rep(0,nComp))
+           Opt.Lambda = as.double(rep(0,nComp)),
+           actset = as.integer(activeset),
+           tuneGam1 = as.double(lambMCP),
+           tuneGam1 = as.double(lambSICA)
     )
   }else if(disFamily == "lnorm"){
     model = "FMAFTR"
@@ -343,7 +589,10 @@ setMethod(f="fmrs.tunsel", definition=function(y,
            conv.eps = as.double(conveps),
            conv.eps.em = as.double(convepsEM),
            GamMixPortion = as.double(gamMixPor),
-           Opt.Lambda = as.double(rep(0,nComp))
+           Opt.Lambda = as.double(rep(0,nComp)),
+           actset = as.integer(activeset),
+           tuneGam1 = as.double(lambMCP),
+           tuneGam1 = as.double(lambSICA)
     )
   }else if(disFamily == "weibull"){
     model = "FMAFTR"
@@ -366,7 +615,10 @@ setMethod(f="fmrs.tunsel", definition=function(y,
            Num.PortionNF = as.double(porNR),
            conv.eps = as.double(convepsNR),
            GamMixPortion = as.double(gamMixPor),
-           Opt.Lambda = as.double(rep(0,nComp))
+           Opt.Lambda = as.double(rep(0,nComp)),
+           actset = as.integer(activeset),
+           tuneGam1 = as.double(lambMCP),
+           tuneGam1 = as.double(lambSICA)
     )
   }else{
     stop("The family of sub-distributions is not specified correctly.")
@@ -382,14 +634,17 @@ setMethod(f="fmrs.tunsel", definition=function(y,
                    lambRidge = lambRidge,
                    disFamily = disFamily,
                    penFamily = penFamily,
-                   model = model
+                   MCPGam = lambMCP,
+                   SICAGam = lambSICA,
+                   model = model,
+                   activeset = array(matrix(c(activeset), nrow=nCov+1, byrow = FALSE),
+                                     dim = c(nCov+1, nComp),
+                                     dimnames = list(xnames,comnames))
   )
   return(lambdafit)
 }
 )
 
-
-
 #' @rdname fmrs.varsel-methods
 #' @aliases fmrs.varsel-method
 setMethod(f="fmrs.varsel", definition=function(y,
@@ -409,7 +664,11 @@ setMethod(f="fmrs.varsel", definition=function(y,
                                                convepsEM = 1e-8,
                                                convepsNR = 1e-8,
                                                porNR = 2,
-                                               gamMixPor = 1){
+                                               gamMixPor = 1,
+                                               activeset,
+                                               lambMCP,
+                                               lambSICA
+                                               ){
   if(missing(y) | !is.numeric(y))
     stop("A numeric response vector must be provided.")
   if(missing(x) | !is.numeric(x))
@@ -417,6 +676,12 @@ setMethod(f="fmrs.varsel", definition=function(y,
   if(missing(delta) & (disFamily!="norm"))
     stop("A censoring indicator vector with 0 or 1 values must be provided.")
 
+  if(missing(lambMCP))
+    lambMCP = 2/(1-max(cor(x)[cor(x)!=1]))
+
+  if(missing(lambSICA))
+    lambSICA = 5.0
+
   if((nComp<2) ) {
     stop("An interger greater than 2 for the order of mixture model
          must be provided.")
@@ -427,10 +692,15 @@ setMethod(f="fmrs.varsel", definition=function(y,
   if(missing(initDispersion)) initDispersion = rep(1,nComp)
   if(missing(initmixProp)) initmixProp = rep(1/nComp,nComp)
 
+  if(missing(activeset)) activeset = matrix(1, nrow = nCov+1, ncol = nComp)
+  if(any(activeset!=0 & activeset!=1))
+    stop("activeset must be a matrix of dimention nCov+1 by nComp with
+         only 0 and 1 values.")
+
   coef0 <- matrix(c(initCoeff), nrow = nComp, ncol = nCov+1, byrow = TRUE)
 
   if(is.null(colnames(x))){
-    xnames <- c("Intercept",c(paste("Cov",1:nCov,sep=".")))
+    xnames <- c("Intercept",c(paste("X",1:nCov,sep=".")))
   } else{
     xnames <- c("Intercept",colnames(x))
   }
@@ -481,7 +751,10 @@ setMethod(f="fmrs.varsel", definition=function(y,
            GIC = as.double(0),
            predict = as.double(rep(0,n*nComp)),
            residual = as.double(rep(0,n*nComp)),
-           tau = as.double(rep(0,n*nComp))
+           tau = as.double(rep(0,n*nComp)),
+           actset = as.integer(activeset),
+           tuneGam1 = as.double(lambMCP),
+           tuneGam1 = as.double(lambSICA)
     )
 
   }else if(disFamily == "lnorm"){
@@ -520,7 +793,10 @@ setMethod(f="fmrs.varsel", definition=function(y,
            GIC = as.double(0),
            predict = as.double(rep(0,n*nComp)),
            residual = as.double(rep(0,n*nComp)),
-           tau = as.double(rep(0,n*nComp))
+           tau = as.double(rep(0,n*nComp)),
+           actset = as.integer(activeset),
+           tuneGam1 = as.double(lambMCP),
+           tuneGam1 = as.double(lambSICA)
     )
   }else if(disFamily == "weibull"){
     model = "FMAFTR"
@@ -560,7 +836,10 @@ setMethod(f="fmrs.varsel", definition=function(y,
            GIC = as.double(0),
            predict = as.double(rep(0,n*nComp)),
            residual = as.double(rep(0,n*nComp)),
-           tau = as.double(rep(0,n*nComp))
+           tau = as.double(rep(0,n*nComp)),
+           actset = as.integer(activeset),
+           tuneGam1 = as.double(lambMCP),
+           tuneGam1 = as.double(lambSICA)
     )
   }else{
     stop("The family of sub-distributions is not specified correctly.")
@@ -588,6 +867,8 @@ setMethod(f="fmrs.varsel", definition=function(y,
              penFamily = penFamily,
              lambPen = array(lambPen, dim = c(1,nComp),dimnames =
                                list(NULL,comnames)),
+             MCPGam = lambMCP,
+             SICAGam = lambSICA,
              model = model,
              fitted = array(matrix(res$predict, nrow = n, byrow = FALSE),
                             dim = c(n, nComp), dimnames =
@@ -597,7 +878,10 @@ setMethod(f="fmrs.varsel", definition=function(y,
                                  list(NULL,comnames)),
              weights = array(matrix(res$tau, nrow = n, byrow = FALSE),
                              dim = c(n, nComp), dimnames =
-                               list(NULL,comnames))
+                               list(NULL,comnames)),
+             activeset = array(matrix(c(activeset), nrow=nCov+1, byrow = FALSE),
+                               dim = c(nCov+1, nComp),
+                               dimnames = list(xnames,comnames))
   )
   return(fit)
 }
@@ -605,9 +889,6 @@ setMethod(f="fmrs.varsel", definition=function(y,
 )
 
 
-
-
-
 #' @rdname fmrs.gendata-methods
 #' @aliases fmrs.gendata-method
 setMethod(f="fmrs.gendata", definition=function(nObs,
