@@ -4,8 +4,10 @@
   fmrsversion <- utils::packageVersion("fmrs")
   fmrsdate <- utils::packageDescription("fmrs")$Date
   fmrsdescrip <- utils::packageDescription("fmrs")$Description
+  fmrsBugReports <- utils::packageDescription("fmrs")$BugReports
   packageStartupMessage(
-    paste('fmrs package, Version ', fmrsversion,', Released ',fmrsdate,' \n',fmrsdescrip, sep = "")
+    paste('fmrs package, Version ',fmrsversion,', Released ',fmrsdate,'\n',
+          fmrsdescrip, '\nBugReports: ',fmrsBugReports , sep = "")
   )
 }
 
