@@ -14,41 +14,40 @@ umax = 40
 ## ------------------------------------------------------------------------
 dat <- fmrs.gendata(nObs = nObs, nComp = nComp, nCov = nCov,
                      coeff = c(coeff1, coeff2), dispersion = dispersion,
-                     mixProp = mixProp, rho = rho, umax = umax, 
+                     mixProp = mixProp, rho = rho, umax = umax,
                      disFamily = "lnorm")
 
 ## ------------------------------------------------------------------------
 res.mle <- fmrs.mle(y = dat$y, x = dat$x, delta = dat$delta,
-                    nComp = nComp, disFamily = "lnorm",
-                    initCoeff = rnorm(nComp*nCov+nComp),
-                    initDispersion = rep(1, nComp),
-                    initmixProp = rep(1/nComp, nComp))
-
+                   nComp = nComp, disFamily = "lnorm",
+                   initCoeff = rnorm(nComp*nCov+nComp),
+                   initDispersion = rep(1, nComp),
+                   initmixProp = rep(1/nComp, nComp))
 coefficients(res.mle)
 dispersion(res.mle)
 mixProp(res.mle)
 
 ## ------------------------------------------------------------------------
 res.lam <- fmrs.tunsel(y = dat$y, x = dat$x, delta = dat$delta,
-                       nComp = nComp, disFamily = "lnorm",
-                       initCoeff = coefficients(res.mle),
-                       initDispersion = dispersion(res.mle),
-                       initmixProp = mixProp(res.mle), 
-                       penFamily = "adplasso")
+                      nComp = nComp, disFamily = "lnorm",
+                      initCoeff = c(coefficients(res.mle)),
+                      initDispersion = dispersion(res.mle),
+                      initmixProp = mixProp(res.mle),
+                      penFamily = "adplasso")
 show(res.lam)
 
 ## ------------------------------------------------------------------------
 res.var <- fmrs.varsel(y = dat$y, x = dat$x, delta = dat$delta,
-                       nComp = nComp, disFamily = "lnorm",
-                       initCoeff = coefficients(res.mle),
-                       initDispersion = dispersion(res.mle),
-                       initmixProp = mixProp(res.mle), 
-                       penFamily = "adplasso",
-                       lambPen = slot(res.lam, "lambPen"))
+                      nComp = ncomp(res.mle), disFamily = "lnorm",
+                      initCoeff=c(coefficients(res.mle)),
+                      initDispersion = dispersion(res.mle),
+                      initmixProp = mixProp(res.mle),
+                      penFamily = "adplasso",
+                      lambPen = slot(res.lam, "lambPen"))
 coefficients(res.var)
 dispersion(res.var)
 mixProp(res.var)
 
 ## ------------------------------------------------------------------------
-round(coefficients(res.var)[-1,],5)
+round(coefficients(res.var)[-1,],3)
 
